import { View, Image, Text } from "@tarojs/components";
import style from './index.module.less'
import { TModelAppConfig } from '@/types/index'
import { APP_NAME_TEXT } from '@/config'

interface Props {
  appConfig: TModelAppConfig;
}

export default ({appConfig}: Props) => {
  const vipMetadata = appConfig?.vips?.find((item)=> item.id === 'vip_plus')?.metadata
  if(!vipMetadata){
    return <></>
  }
  return (
    <View className={style.wrap}>
      <View className="flex items-center justify-center w-full mb-30">
        <View className={style.centerIcon}>
          <View className={style.centerIconSmallSquare}></View>
          <View className={style.centerIconSquare}></View>
        </View>
        <View className="text-16 font-medium leading-24">尊享六大权益</View>
        <View className={style.rightIcon}>
          <View className={style.centerIconSmallSquare}></View>
          <View className={style.centerIconSquare}></View>
        </View>
      </View>
      <View className="flex flex-col w-full gap-26">
        <View className="flex flex-wrap justify-between items-center  w-full">
          <View className={`flex gap-8 ${style.item}`}>
            <View className="w-40 h-40">
              <Image src='https://cdn.wehome.cn/cmn/png/70/META-H8UK0IWU-LIGPDI0B88LDCAMAO6LN3-OXMJWI2M-971.png' mode="widthFix" className="w-40 h-40"></Image>
            </View>
            <View className="flex flex-col">
              <Text className="text-12 text-black leading-18">创建多个{APP_NAME_TEXT}</Text>
              <Text className="text-11 text-gray-45 leading-18 whitespace-nowrap">最大支持创建{vipMetadata.maxCharacterNum}个</Text>
            </View>
          </View>
          
          <View className={`flex gap-8 ${style.item} ${style.disabled}`}>
            <View className="w-40 h-40">
              <Image src='https://cdn.wehome.cn/cmn/png/43/META-H8UK0IWU-LIGPDI0B88LDCAMAO6LN3-3YMJWI2M-A71.png' mode="widthFix" className="w-40 h-40"></Image>
            </View>
            <View className="flex flex-col">
              <Text className="text-12 text-black leading-18">自定义背景</Text>
              <Text className="text-11 text-gray-45 leading-18">支持图片上传</Text>
            </View>
          </View>
        </View>

        <View className="flex flex-wrap justify-between items-center w-full">
          <View className={`flex gap-8 ${style.item}`}>
            <View className="w-40 h-40">
              <Image src='https://cdn.wehome.cn/cmn/png/254/META-H8UKVHWU-KIGP3BIL7M5AYC6XHNUA2-YXMJWI2M-P91.png' mode="widthFix" className="w-40 h-40"></Image>
            </View>
            <View className="flex flex-col">
              <Text className="text-12 text-black leading-18">克隆音色对话</Text>
              <Text className="text-11 text-gray-45 leading-12 whitespace-nowrap">{vipMetadata.cloneVoiceChatDuration/60}分钟/天时长</Text>
            </View>
          </View>
          <View className={`flex gap-8 ${style.item}`}>
            <View className="w-40 h-40">
              <Image src='https://cdn.wehome.cn/cmn/png/131/META-H8UK0IWU-LIGPDI0B88LDCAMAO6LN3-BYMJWI2M-B71.png' mode="widthFix" className="w-40 h-40"></Image>
            </View>
            <View className="flex flex-col">
              <Text className="text-12 text-black leading-18">搭建知识库</Text>
              <Text className="text-11 text-gray-45 leading-18">{vipMetadata.maxDocSize}M文档上传容量</Text>
            </View>
          </View>
        </View>
        
        <View className="flex flex-wrap justify-between items-center w-full">
          <View className={`flex gap-8 ${style.item}`}>
            <View className="w-40 h-40">
              <Image src='https://cdn.wehome.cn/cmn/png/150/META-H8UKVHWU-KIGP3BIL7M5AYC6XHNUA2-3YMJWI2M-Q91.png' mode="widthFix" className="w-40 h-40"></Image>
            </View>
            <View className="flex flex-col">
              <Text className="text-12 text-black leading-18">AI 对话记录</Text>
              <Text className="text-11 text-gray-45 leading-18 whitespace-nowrap">支持查看聊天内容</Text>
            </View>
          </View>
          
          <View className={`flex gap-8 ${style.item}`}>
            <View className="w-40 h-40">
              <Image src='https://cdn.wehome.cn/cmn/png/190/META-H8UK0IWU-LIGPDI0B88LDCAMAO6LN3-BYMJWI2M-C71.png' mode="widthFix" className="w-40 h-40"></Image>
            </View>
            <View className="flex flex-col">
              <Text className="text-12 text-black leading-18">访问数据统计</Text>
              <Text className="text-11 text-gray-45 leading-18 whitespace-nowrap">支持查看访问数据</Text>
            </View>
          </View>
        </View>
      </View>
    </View>
  );
};
