import LeafTabs from "@/components/leaf-tabs/index";
import VoicePlayerBar, { IVoicePlayerBar } from "@/components/voice-player-bar";
import SystemVoice from "@/pages/system-voice/index";
import CloneVoice from "@/pages/voice/index";
import { TServiceAudioModel } from "@/types";
import { View } from "@tarojs/components";
import { useRouter } from "@tarojs/taro";
import React, { useMemo, useRef, useState } from "react";
import PageWrapper from '@/components/page-wrapper'
import styles from "./index.module.less";

interface Props {}
type ExtendedTServiceAudioModel = TServiceAudioModel & { checked: boolean };
const VoiceTabs: React.FC<Props> = ({}) => {
  const playerRef = useRef<IVoicePlayerBar>(null);
  const [sysVoice, setSysVoice] = useState<ExtendedTServiceAudioModel | null>(
    null,
  );

  const [voiceName, setVoiceName] = useState("");
  const [voiceAlias, setVoiceAlias] = useState("");
  const [voiceIdx, setVoiceIdx] = useState(-1);
  const router = useRouter();
  const profileId = router.params.profileId || "";
  const [tabs] = useState([
    {
      label: "克隆声音",
      id: 0,
    },
    {
      label: "系统声音",
      id: 1,
    },
  ]);
  const [activeKey, setActiveKey] = useState(0);

  const tabsMemo = useMemo(() => {
    return tabs;
  }, [tabs]);

  const handleTabClickAction = (id: number) => {
    setActiveKey(id);
  };

  const handlePlayAction = (voiceItem: any, type: "system" | "cloned") => {
    if (type == "system") {
      setVoiceName("");
      setVoiceAlias("");
      setVoiceIdx(-1);

      setSysVoice(voiceItem);
      playerRef.current && playerRef.current.play(voiceItem.voice);
    } else {
      setSysVoice(null);
      setVoiceName(voiceItem.voiceName);
      setVoiceAlias(voiceItem.voiceAlias)
      setVoiceIdx(voiceItem.voiceIndex);
      playerRef.current && playerRef.current.play(voiceItem.voiceName);
    }
  };

  return (
    <PageWrapper>
      <View className={styles.container}>
        <View className={styles.playContainer}>
          <VoicePlayerBar
            ref={playerRef}
            voiceItem={sysVoice}
            voiceName={voiceName}
            voiceNameText={voiceIdx == -1 ? "" : voiceAlias}
          />
        </View>
        <LeafTabs tabs={tabsMemo} onTabChange={handleTabClickAction} />
        <View className={styles.content}>
          {activeKey == 0 && (
            <CloneVoice
              profileId={profileId}
              onPlay={(item) => {
                handlePlayAction(item, "cloned");
              }}
            ></CloneVoice>
          )}
          {activeKey == 1 && (
            <SystemVoice
              profileId={profileId}
              onPlay={(item) => {
                handlePlayAction(item, "system");
              }}
            ></SystemVoice>
          )}
        </View>
      </View>
    </PageWrapper>
  );
};

export default VoiceTabs;
